@@ -4,7 +4,6 @@ import keyboard as kb
 
 def select(array: list):
     row = 0
-    accept = True
     a_len = 7
     for x in array:
         if len(x) > a_len: a_len = len(x)
@@ -19,33 +18,31 @@ def select(array: list):
     heat.append('│'+'─'*a_len+'│')
 
     while True:
-        if accept:
-            field = heat.copy()
-            for row_, row_data in enumerate(array):
-                free = a_len - len(row_data)
-                if row_ == row: 
-                    row_data = f'[{row_data}]'
-                    free -= 2
+        field = heat.copy()
+        for row_, row_data in enumerate(array):
+            free = a_len - len(row_data)
+            if row_ == row: 
+                row_data = f'[{row_data}]'
+                free -= 2
 
-                left = free//2
-                right = free - left
+            left = free//2
+            right = free - left
 
-                field.append('│'+' '*left+row_data+' '*right+'│')
-            field.append('└'+'─'*a_len+'┘')
+            field.append('│'+' '*left+row_data+' '*right+'│')
+        field.append('└'+'─'*a_len+'┘')
 
-            for row_data in field:
-                print(row_data)
+        for row_data in field:
+            print(row_data)
 
         key = kb.read_key()
-
-        if accept: accept = False
-        else:
-            accept = True
-            continue
+        kb.read_key()
 
         if key == 'up': row -= 1
         elif key == 'down': row += 1
         elif key == 'enter':
+            for _ in range(row_len+4):
+                sys.stdout.write("\033[F")
+                sys.stdout.write("\033[K")
             return row
 
         for _ in range(row_len+4):
